@@ -31,7 +31,6 @@ use image::tiff::TiffEncoder;
 use image::{
 	AnimationDecoder, ColorType, ExtendedColorType, ImageEncoder, ImageFormat,
 };
-use std::convert::TryInto;
 use std::fmt::Debug;
 use std::fs::{self, File};
 use std::io::{self, Read, Write};
@@ -50,6 +49,8 @@ pub enum AppError {
 	Image(#[from] image::error::ImageError),
 	#[error("GIF encoding error: `{0}`")]
 	GifEncoding(#[from] gif::EncodingError),
+	#[error("PNG encoding error: `{0}`")]
+	PngEncoding(#[from] png::EncodingError),
 	#[cfg(feature = "ski")]
 	#[error("gifski error: `{0}`")]
 	Gifski(#[from] gifski::Error),
@@ -586,9 +587,10 @@ where
 		ApngEncoder::new(
 			images.len().try_into().unwrap_or_default(),
 			geometry,
+			output,
 			&self.settings.anim,
-		)
-		.save(images, self.settings.input_state, output);
+		)?
+		.save(images, self.settings.input_state)?;
 		Ok(())
 	}
 }
